attention module — parsanlp 1.0.3 documentation

# attention module

class attention.AttentionHead(*args, **kwargs)

  Bases: `Layer`

  A class representing a single attention head in a multi-head attention mechanism.

  Parameters:

    dmodel (int) – The dimensionality of the model.

  call(input)

    This is where the layer’s logic lives.

    The call() method may not create state (except in its first invocation, wrapping the creation of variables or other resources in tf.init_scope()). It is recommended to create state in __init__(), or the build() method that is called automatically before call() executes the first time.

    Parameters:

      - inputs –

        Input tensor, or dict/list/tuple of input tensors. The first positional inputs argument is subject to special rules: - inputs must be explicitly passed. A layer cannot have zero

        > arguments, and inputs cannot be provided via the default value of a keyword argument.

        - NumPy array or Python scalar values in inputs get cast as tensors.

        - Keras mask metadata is only collected from inputs.

        - Layers are built (build(input_shape) method) using shape info from inputs only.

        - input_spec compatibility is only checked against inputs.

        - Mixed precision input casting is only applied to inputs. If a layer has tensor arguments in *args or **kwargs, their casting behavior in mixed precision should be handled manually.

        - The SavedModel input specification is generated using inputs only.

        - Integration with various ecosystem packages like TFMOT, TFLite, TF.js, etc is only supported for inputs and not for tensors in positional and keyword arguments.

      - *args – Additional positional arguments. May contain tensors, although this is not recommended, for the reasons above.

      - **kwargs –

        Additional keyword arguments. May contain tensors, although this is not recommended, for the reasons above. The following optional keyword arguments are reserved: - training: Boolean scalar tensor of Python boolean indicating

        > whether the call is meant for training or inference.

        - mask: Boolean input mask. If the layer’s call() method takes a mask argument, its default value will be set to the mask generated for inputs by the previous layer (if input did come from a layer that generated a corresponding mask, i.e. if it came from a Keras layer with masking support).

    Returns:

      A tensor or list/tuple of tensors.

class attention.MultiHeadAttention(*args, **kwargs)

  Bases: `Layer`

  A class representing multi-head attention mechanism.

  Parameters:

    - h (int) – Number of attention heads.

    - dmodel (int) – The dimensionality of the model. Aka the output vector dims.

  call(input)

    This is where the layer’s logic lives.

    The call() method may not create state (except in its first invocation, wrapping the creation of variables or other resources in tf.init_scope()). It is recommended to create state in __init__(), or the build() method that is called automatically before call() executes the first time.

    Parameters:

      - inputs –

        Input tensor, or dict/list/tuple of input tensors. The first positional inputs argument is subject to special rules: - inputs must be explicitly passed. A layer cannot have zero

        > arguments, and inputs cannot be provided via the default value of a keyword argument.

        - NumPy array or Python scalar values in inputs get cast as tensors.

        - Keras mask metadata is only collected from inputs.

        - Layers are built (build(input_shape) method) using shape info from inputs only.

        - input_spec compatibility is only checked against inputs.

        - Mixed precision input casting is only applied to inputs. If a layer has tensor arguments in *args or **kwargs, their casting behavior in mixed precision should be handled manually.

        - The SavedModel input specification is generated using inputs only.

        - Integration with various ecosystem packages like TFMOT, TFLite, TF.js, etc is only supported for inputs and not for tensors in positional and keyword arguments.

      - *args – Additional positional arguments. May contain tensors, although this is not recommended, for the reasons above.

      - **kwargs –

        Additional keyword arguments. May contain tensors, although this is not recommended, for the reasons above. The following optional keyword arguments are reserved: - training: Boolean scalar tensor of Python boolean indicating

        > whether the call is meant for training or inference.

        - mask: Boolean input mask. If the layer’s call() method takes a mask argument, its default value will be set to the mask generated for inputs by the previous layer (if input did come from a layer that generated a corresponding mask, i.e. if it came from a Keras layer with masking support).

    Returns:

      A tensor or list/tuple of tensors.